==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Nagrywanie wideo w trakcie. Czy na pewno chcesz zamknąć okno? </translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otwórz folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Zdjęcie</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Zmień kamerę</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Wydrukuj</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nie masz uprawnień do operowania na tym folderze</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Nieprawidłowy folder</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Podstawowy</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokalizacja pliku</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Zrób zdjęcie</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Tryb zdjęć seryjnych</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Opóźnienie samowyzwalacza</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format wyjściowy</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 sztuki</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 sztuk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera to narzędzie do przechwytywania obrazów i wideo za pomocą kamery komputera lub kamery internetowej.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Plik nie został zapisany</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Zapisz do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Zdjęcie:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Wideo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ustawienia rozdzielczości</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rozdzielczość:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Zdjęcia:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Wideo:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efekty dźwiękowe</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Tryb lustrzany</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Latarka</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zatrzymaj nagrywanie</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Wydrukuj</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Pokaż skróty</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Przestań robić zdjęcia</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu kontekstowe</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Zrobić zdjęcie</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Nagraj wideo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Przestań robić zdjęcia</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalny</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Żywy</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Ciepły</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Chłodny</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szary</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Latarka</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Wł</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Wył</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Opóźnij migawkę</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtry</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Odsłonięcie</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nie znaleziono kamery internetowej</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera internetowa jest używana</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zatrzymaj nagrywanie</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Nagrywanie wideo w trakcie. Czy na pewno zamknąć okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otwórz folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Zdjęcie</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Zmień kamerę</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nie posiadasz uprawnień do wykonywania działań na tym folderze</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Nieprawidłowy folder</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Podstawowe</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Położenie pliku</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Zrób zdjęcie</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Tryb seryjny</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Opóźnienie samowyzwalacza</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format wyjściowy</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 sztuki</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 sztuk</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera to narzędzie do przechwytywania obrazów i wideo za pomocą wbudowanej lub zewnętrznej kamery internetowej.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Plik nie został zapisany</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Zapisz do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Zdjęcie:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Wideo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ustawienia rozdzielczości</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rozdzielczość:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Zdjęcia:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Wideo:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efekty dźwiękowe</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Tryb lustrzany</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Latarka</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Linie siatki</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 linii</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 linii</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Maksymalna rozdzielczość:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zatrzymaj nagrywanie</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Pokaż skróty</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Przestań robić zdjęcia</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu kontekstowe</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Zrób zdjęcie</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Nagraj wideo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Przestań robić zdjęcia</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalny</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Żywy</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Ciepły</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Chłodny</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Szary</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Latarka</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Wł</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Wył</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Opóźnienie przechwytywania</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtry</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspozycja</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nie znaleziono kamery internetowej</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Kamera internetowa jest już w użyciu</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zatrzymaj nagrywanie</translation>
    </message>
</context>
</TS>
